#[repr(transparent)]pub struct RoomDetails {
inner: TypedObjectRef<RoomDetails, <RoomDetails as ObjectSubclass>::ParentType>,
phantom: PhantomData<()>,
}Expand description
Preference Window to display and update room details.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<RoomDetails, <RoomDetails as ObjectSubclass>::ParentType>phantom: PhantomData<()>Implementations
Sourceimpl RoomDetails
impl RoomDetails
Sourcepub fn members(&self) -> <OnceCell<MemberList> as Property>::Value
pub fn members(&self) -> <OnceCell<MemberList> as Property>::Value
The list of members in the room.
Sourcepub fn timeline(&self) -> <OnceCell<HistoryViewerTimeline> as Property>::Value
pub fn timeline(&self) -> <OnceCell<HistoryViewerTimeline> as Property>::Value
The timeline for the history viewers.
Sourcepub fn connect_room_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_room_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the room property
Sourcepub fn connect_members_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_members_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the members property
Sourcepub fn connect_timeline_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_timeline_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the timeline property
Sourcepub fn notify_room(&self)
pub fn notify_room(&self)
Notify listeners of a change in the room property
Sourcepub fn notify_members(&self)
pub fn notify_members(&self)
Notify listeners of a change in the members property
Sourcepub fn notify_timeline(&self)
pub fn notify_timeline(&self)
Notify listeners of a change in the timeline property
Sourceimpl RoomDetails
impl RoomDetails